@@ -11,18 +11,20 @@ import java.util.Map;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 
+import com.ozacc.mail.impl.Cp932;
+
 /**
  * ᡼롣
  * 
  * @since 1.0
  * @author Tomohiro Otsuka
- * @version $Id: Mail.java,v 1.5 2004/09/13 07:10:35 otsuka Exp $
+ * @version $Id: Mail.java,v 1.7 2004/09/14 00:04:57 otsuka Exp $
  */
 public class Mail {
 
 	/** <code>ISO-2022-JP</code> */
 	public static final String JIS_CHARSET = "ISO-2022-JP";
-	
+
 	public static final String DOCTYPE_PUBLIC = "-//OZACC//DTD MAIL//EN";
 
 	public static final String DOCTYPE_SYSTEM = "http://www.ozacc.com/library/dtd/ozacc-mail.dtd";
@@ -68,6 +70,27 @@ public class Mail {
 		this.charset = charset;
 	}
 
+	/**
+	 * ԡ󥹥ȥ饯
+	 * 
+	 * @since 1.0.2
+	 * 
+	 * @param original ԡMail󥹥
+	 */
+	public Mail(Mail original) {
+		this.bcc = original.bcc;
+		this.cc = original.cc;
+		this.charset = original.charset;
+		this.from = original.from;
+		this.importance = original.importance;
+		this.replyTo = original.replyTo;
+		this.returnPath = original.returnPath;
+		this.subject = original.subject;
+		this.text = original.text;
+		this.to = original.to;
+		this.xHeaders = original.xHeaders;
+	}
+
 	/**
 	 * 󥳡ɤ˻Ѥʸɤ֤ޤ
 	 * 
@@ -139,6 +162,9 @@ public class Mail {
 	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
 	 */
 	public void addTo(String email, String name) throws IllegalArgumentException {
+		if (charset.equals(JIS_CHARSET)) {
+			name = Cp932.toJIS(name);
+		}
 		try {
 			addTo(new InternetAddress(email, name, charset));
 		} catch (UnsupportedEncodingException e) {
@@ -194,6 +220,9 @@ public class Mail {
 	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
 	 */
 	public void addCc(String email, String name) throws IllegalArgumentException {
+		if (charset.equals(JIS_CHARSET)) {
+			name = Cp932.toJIS(name);
+		}
 		try {
 			addCc(new InternetAddress(email, name, charset));
 		} catch (UnsupportedEncodingException e) {
@@ -285,6 +314,9 @@ public class Mail {
 	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
 	 */
 	public void setFrom(String email, String name) throws IllegalArgumentException {
+		if (charset.equals(JIS_CHARSET)) {
+			name = Cp932.toJIS(name);
+		}
 		try {
 			setFrom(new InternetAddress(email, name, charset));
 		} catch (UnsupportedEncodingException e) {
@@ -490,11 +522,38 @@ public class Mail {
 		}
 	}
 
+	/**
+	 * åȤƤ襢ɥ쥹(Toɥ쥹)ƥꥢޤ
+	 *
+	 * @since 1.0.2
+	 */
+	public void clearTo() {
+		to = null;
+	}
+
+	/**
+	 * åȤƤCCɥ쥹ƥꥢޤ
+	 *
+	 * @since 1.0.2
+	 */
+	public void clearCc() {
+		cc = null;
+	}
+
+	/**
+	 * åȤƤBCCɥ쥹ƥꥢޤ
+	 *
+	 * @since 1.0.2
+	 */
+	public void clearBcc() {
+		bcc = null;
+	}
+
 	/**
 	 * ᡼ν١Τߤ
 	 * 
 	 * @author Tomohiro Otsuka
-	 * @version $Id: Mail.java,v 1.5 2004/09/13 07:10:35 otsuka Exp $
+	 * @version $Id: Mail.java,v 1.7 2004/09/14 00:04:57 otsuka Exp $
 	 */
 	public static class Importance {
 
